import java.sql.*;
/**
 * this class is a higher level abstraction of the JDBC ResultSet object
 */
class resultSet {

	ResultSet rs;
	ResultSetMetaData rsmetadata;
	int numCols;
	
	String[] metadata;

	public resultSet(ResultSet rset) {
		rs = rset;
		try {
			//get the meta data and column count at once
			rsmetadata = rs.getMetaData();
			numCols = rsmetadata.getColumnCount();
		} catch (Exception e) {
			System.out.println("resultset error" + e.getMessage());
		}
	}
	/**
	 * @returns an array of all the column names or other meta data
	 */
	public String[] getMetaData(){
		metadata = new String[numCols];
		try {
			for (int i = 1; i <= numCols; i++)
				metadata[i - 1] = rsmetadata.getColumnName(i);
		} catch (Exception e) {
			System.out.println("meta data error" + e.getMessage());
		}
		return metadata;
	}

	//-----------------------------------
	public boolean hasMoreElements() {
		try {
			return rs.next();
		} catch (Exception e) {
			System.out.println("next error " + e.getMessage());
			return false;
		}
	}
	/**
	 * copies contents of row into string array
	 * @return the contents of row
	 */
	public String[] nextElement() {
		String[] row = new String[numCols];
		try {
			for (int i = 1; i <= numCols; i++)
				row[i - 1] = rs.getString(i);
		} catch (Exception e) {
			System.out.println("next element error" + e.getMessage());
		}
		return row;
	}
	/**
	 * @param columnName
	 * @return the value of a column
	 */
	public String getColumnValue(String columnName) {
		String res = "";
		try {
			res = rs.getString(columnName);
		} catch (Exception e) {
			System.out.println("Column value error:" + columnName + e.getMessage());
		}
		return res;
	}
	/**
	 * @param i : column id int the resultset
	 * @return the value of a column
	 */
	public String getColumnValue(int i) {
		String res = "";
		try {
			res = rs.getString(i);
		} catch (Exception e) {
			System.out.println("Column value error: " + i + " " + e.getMessage());
		}
		return res;
	}
	/**
	 * @param columnName
	 * @return type of column
	 */
	public String getColumnType(String columnName) {
		String res = "";
		try {
			res = rsmetadata.getColumnTypeName(1);
		} catch (Exception e) {
			System.out.println("Column value error:" + columnName + e.getMessage());
		}
		return res;
	}
	/**
	 * close the resultSet
	 */
	public void close() {
		try {
			rs.close();
		} catch (Exception e) {
			System.out.println(e.getMessage());
		}
	}
}
