import java.util.Properties;
import java.io.FileInputStream;
import java.io.IOException;

/**
 * this class is a higher level abstraction of the Properties object
 */
public class Config {

	private Properties prop;
	private FileInputStream configFile;
	private String result;
	
	/**
	 * Load a properties file
	 * @param fileName : properties file name
	 */
	public Config(String fileName){		
		try {
		    System.out.println("[+] Loading config file : " + fileName + ".");
		    prop = new Properties();
			configFile = new FileInputStream(fileName);
			prop.load(configFile);
			configFile.close();			
		} catch (IOException e) {
			System.err.println("[-] Loading config file : " + fileName + " not found.");
			System.exit(-1);
		}
	}
	
	/**
	 * Look for the property associated to an input key and returns this property.
	 * In case no properties match to the input key, it returns a default string 
	 * "!! undefined !!"
	 * @param name : property key name
	 * @return the property values matching the property key name 
	 */
	public String getProperty(String name) {
		result="";
		try {
			result = prop.getProperty(name,"!!_NOT_FOUND_!!");
		} catch (Exception e) {
			System.out.println("getProperty error:" + name + e.getMessage());
		}
		return result;
	}
}
